@@ -29,22 +29,29 @@
 G_BEGIN_DECLS
 
 GList		*gs_plugin_loader_get_installed		(GsPluginLoader	*plugin_loader,
+							 GsPluginLoaderFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_updates		(GsPluginLoader	*plugin_loader,
+							 GsPluginLoaderFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_popular		(GsPluginLoader	*plugin_loader,
+							 GsPluginLoaderFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_categories	(GsPluginLoader	*plugin_loader,
+							 GsPluginLoaderFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 GList		*gs_plugin_loader_get_category_apps	(GsPluginLoader	*plugin_loader,
 							 GsCategory	*category,
+							 GsPluginLoaderFlags flags,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
 G_END_DECLS
 
 #endif /* __GS_PLUGIN_LOADER_SYNC_H */
+
+/* vim: set noexpandtab: */
