@@ -120,7 +120,12 @@ gs_shell_installed_finished_func (GsPluginLoader *plugin_loader, GsApp *app, gpo
 	if (app != NULL) {
 		remove_row (GTK_LIST_BOX (priv->list_box_installed),
 			    GTK_WIDGET (helper->app_widget));
+	} else {
+		gs_app_notify_failed_modal (priv->builder,
+					    gs_app_widget_get_app (helper->app_widget),
+					    FALSE, NULL);
 	}
+
 	g_object_unref (helper->app_widget);
 	g_object_unref (helper->shell_installed);
 	g_free (helper);
@@ -343,6 +348,13 @@ gs_shell_installed_sort_func (GtkListBoxRow *a,
 	guint64 date1 = gs_app_get_install_date (a1);
 	guint64 date2 = gs_app_get_install_date (a2);
 
+	if (gs_app_get_kind (a1) == GS_APP_KIND_SYSTEM &&
+	    gs_app_get_kind (a2) != GS_APP_KIND_SYSTEM)
+		return 1;
+	if (gs_app_get_kind (a1) != GS_APP_KIND_SYSTEM &&
+	    gs_app_get_kind (a2) == GS_APP_KIND_SYSTEM)
+		return -1;
+
 	if (date1 < date2)
 		return 1;
 	else if (date2 < date1)
@@ -362,15 +374,9 @@ gs_shell_installed_list_header_func (GtkListBoxRow *row,
 {
 	GtkWidget *header;
 
-	/* first entry */
-	header = gtk_list_box_row_get_header (row);
-	if (before == NULL) {
-		gtk_list_box_row_set_header (row, NULL);
-		return;
-	}
-
-	/* already set */
-	if (header != NULL)
+	/* reset */
+	gtk_list_box_row_set_header (row, NULL);
+	if (before == NULL)
 		return;
 
 	/* set new */
