@@ -199,10 +199,12 @@ save_back_entry (GsShell *shell)
 	entry->mode = priv->mode;
 
 	if (priv->mode == GS_SHELL_MODE_CATEGORY) {
+		g_clear_object (&entry->category);
 		entry->category = gs_shell_category_get_category (priv->shell_category);
 		g_object_ref (entry->category);
 	}
 	else if (priv->mode == GS_SHELL_MODE_DETAILS) {
+		g_clear_object (&entry->app);
 		entry->app = gs_shell_details_get_app (priv->shell_details);
 		g_object_ref (entry->app);
 	}
@@ -614,6 +616,7 @@ gs_shell_finalize (GObject *object)
 	GsShell *shell = GS_SHELL (object);
 	GsShellPrivate *priv = shell->priv;
 
+	g_slist_free_full (priv->back_entry_stack, (GDestroyNotify) free_back_entry);
 	g_object_unref (priv->builder);
 	g_object_unref (priv->cancellable);
 	g_object_unref (priv->plugin_loader);
