@@ -34,6 +34,10 @@ void	 gs_container_remove_all	(GtkContainer	*container);
 void	 gs_grab_focus_when_mapped	(GtkWidget	*widget);
 
 void	 gs_app_notify_installed	(GsApp		*app);
+void	 gs_app_notify_failed_modal	(GtkBuilder	*builder,
+					 GsApp		*app,
+					 gboolean	 is_install,
+					 const GError	*error);
 
 guint	 gs_string_replace		(GString	*string,
 					 const gchar	*search,
