@@ -191,6 +191,8 @@ appstream_cache_icon_kind_from_string (const gchar *kind_str)
 {
 	if (g_strcmp0 (kind_str, "stock") == 0)
 		return APPSTREAM_APP_ICON_KIND_STOCK;
+	if (g_strcmp0 (kind_str, "remote") == 0)
+		return APPSTREAM_APP_ICON_KIND_REMOTE;
 	if (g_strcmp0 (kind_str, "local") == 0 ||
 	    g_strcmp0 (kind_str, "cached") == 0)
 		return APPSTREAM_APP_ICON_KIND_CACHED;
@@ -203,6 +205,7 @@ typedef struct {
 	char			*lang_temp;
 	AppstreamCache		*cache;
 	AppstreamCacheSection	 section;
+	AppstreamCacheSection	 section_last_known;
 } AppstreamCacheHelper;
 
 /**
@@ -302,6 +305,8 @@ appstream_cache_start_element_cb (GMarkupParseContext *context,
 		break;
 	default:
 		/* ignore unknown entries */
+		if (helper->section != APPSTREAM_CACHE_SECTION_UNKNOWN)
+			helper->section_last_known = helper->section;
 		break;
 	}
 
@@ -417,7 +422,7 @@ appstream_cache_end_element_cb (GMarkupParseContext *context,
 		break;
 	default:
 		/* ignore unknown entries */
-		helper->section = APPSTREAM_CACHE_SECTION_APPLICATION;
+		helper->section = helper->section_last_known;
 		break;
 	}
 }
@@ -474,14 +479,19 @@ appstream_cache_text_cb (GMarkupParseContext *context,
 		appstream_app_set_id (helper->item_temp, text, text_len);
 		break;
 	case APPSTREAM_CACHE_SECTION_PKGNAME:
-		if (helper->item_temp == NULL ||
-		    appstream_app_get_pkgname (helper->item_temp) != NULL) {
+		if (helper->item_temp == NULL) {
 			g_set_error_literal (error,
 					     APPSTREAM_CACHE_ERROR,
 					     APPSTREAM_CACHE_ERROR_FAILED,
 					     "item_temp pkgname invalid");
 			return;
 		}
+		if (appstream_app_get_pkgname (helper->item_temp) != NULL) {
+			g_debug ("multiple pkgname's for %s, ignoring %s",
+				 appstream_app_get_id (helper->item_temp),
+				 text);
+			return;
+		}
 		appstream_app_set_pkgname (helper->item_temp, text, text_len);
 		break;
 	case APPSTREAM_CACHE_SECTION_NAME:
